==> kvirc-trinity-14.0.9.tar.xz: kvirc-trinity-14.0.9/src/kvirc/kvs/kvi_kvs_treenode_specialcommand.cpp <==
//=============================================================================
//
//   File : kvi_kvs_treenode_specialcommand.cpp
//   Created on Thu 09 Oct 2003 02:20:12 by Szymon Stefanek
//
//   This file is part of the KVIrc IRC client distribution
//   Copyright (C) 2003 Szymon Stefanek <pragma at kvirc dot net>
//
//   This program is FREE software. You can redistribute it and/or
//   modify it under the terms of the GNU General Public License
//   as published by the Free Software Foundation; either version 2
//   of the License, or (at your opinion) any later version.
//
//   This program is distributed in the HOPE that it will be USEFUL,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//   See the GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program. If not, write to the Free Software Foundation,
//   Inc. ,51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
//
//=============================================================================

#define __KVIRC__

#include "kvi_kvs_treenode_specialcommand.h"

KviKvsTreeNodeSpecialCommand::KviKvsTreeNodeSpecialCommand(const TQChar * pLocation,const TQString &szCmdName)
: KviKvsTreeNodeCommand(pLocation,szCmdName)
{
}

KviKvsTreeNodeSpecialCommand::~KviKvsTreeNodeSpecialCommand()
{
}

void KviKvsTreeNodeSpecialCommand::contextDescription(TQString &szBuffer)
{
#ifdef COMPILE_NEW_KVS
	szBuffer = "Special Command \"";
	szBuffer += m_szCmdName;
	szBuffer += "\"";
#endif
}


void KviKvsTreeNodeSpecialCommand::dump(const char * prefix)
{
#ifdef COMPILE_NEW_KVS
	debug("%s SpecialCommand(%s)",prefix,m_szCmdName.utf8().data());
	dumpSwitchList(prefix);
#endif
}

==> kvirc-trinity-14.1.5.tar.xz: kvirc-trinity-14.1.5/src/kvirc/kvs/kvi_kvs_treenode_specialcommand.cpp <==
//=============================================================================
//
//   File : kvi_kvs_treenode_specialcommand.cpp
//   Created on Thu 09 Oct 2003 02:20:12 by Szymon Stefanek
//
//   This file is part of the KVIrc IRC client distribution
//   Copyright (C) 2003 Szymon Stefanek <pragma at kvirc dot net>
//
//   This program is FREE software. You can redistribute it and/or
//   modify it under the terms of the GNU General Public License
//   as published by the Free Software Foundation; either version 2
//   of the License, or (at your opinion) any later version.
//
//   This program is distributed in the HOPE that it will be USEFUL,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//   See the GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program. If not, write to the Free Software Foundation,
//   Inc. ,51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
//
//=============================================================================

#define __KVIRC__

#include "kvi_kvs_treenode_specialcommand.h"

KviKvsTreeNodeSpecialCommand::KviKvsTreeNodeSpecialCommand(const TQChar * pLocation,const TQString &szCmdName)
: KviKvsTreeNodeCommand(pLocation,szCmdName)
{
}

KviKvsTreeNodeSpecialCommand::~KviKvsTreeNodeSpecialCommand()
{
}

void KviKvsTreeNodeSpecialCommand::contextDescription(TQString &szBuffer)
{
#ifdef COMPILE_NEW_KVS
	szBuffer = "Special Command \"";
	szBuffer += m_szCmdName;
	szBuffer += "\"";
#endif
}


void KviKvsTreeNodeSpecialCommand::dump(const char * prefix)
{
#ifdef COMPILE_NEW_KVS
	tqDebug("%s SpecialCommand(%s)",prefix,m_szCmdName.utf8().data());
	dumpSwitchList(prefix);
#endif
}
